@@ -3,13 +3,14 @@
    and a  simplified version of MEP model for the simulation of the 
    semiclassical Boltzmann equation for both electrons and holes.
    It also includes the quantum effects by means of effective
-   potential method.
+   potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -25,9 +26,9 @@
 
 // =================================================================
 // File Name : mainArchimedes.c
-// Version   : release 0.0.7
+// Version   : release 0.0.9
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 27 Dec.2006, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 07 September 2007, Cassibile (SR), Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -48,14 +49,14 @@
 // Preprocessor Definitions
 #define real double
 #define MN3 4
-#define NXM 308
-#define NYM 308
+#define NXM 158
+#define NYM 158
 #define DIME 2003
 #define ITMAX 10000000
 #define POISSONITMAX 1500
 #define SMALL 1.e-5
 #define VMAX 1000000
-#define NPMAX 10000000 // maximum number of super-particles
+#define NPMAX 5000000 // maximum number of super-particles
 #define MCE 0  // MCE stands for MC for electrons only
 #define MCH 1  // MCH stands for MC for holes only
 #define MCEH 2 // MCEH stands for MC both for electrons and holes
@@ -64,9 +65,16 @@
 #define MEPEH 5 // MEPEH stands for MEP model for electrons and holes
 #define GNUPLOTFORMAT 0 // output file in GNUPLOT format
 #define MESHFORMAT 1 // output file in Mesh format
-#define SILICON 0 // flag for Silicon material
-#define GAAS 1 // flag for GaAs material
-#define GERMANIUM 2 // flag for Germanium material
+
+// definition of the material reference table
+#define NOAMTIA 3   // Number Of All Material Taken Into Account (excluding SiO2)
+// ********************
+#define iSIO2 -1      // reference number to Silicon Oxide
+#define SILICON 0    // reference number to Silicon
+#define GAAS 1       // reference number to GaAs
+#define GERMANIUM 2  // reference number to Germanium
+// ********************
+
 #define NUMSIO2 2 // maximum number of SiO2 interfaces
 
 // ===============================
@@ -83,12 +91,17 @@ int NUM_VERT,NUM_EXAHEDRA,MEDIA,MAXIMINI;
 int SAVEALWAYS;
 int nx,ny;
 int ISEED,NP1,INUM,IV;
-int c,Model_Number,File_Format,Material,Quantum_Flag;
+int c,Model_Number,File_Format,Quantum_Flag;
 int leid_flag;
 int SIO2_UP_FLAG;
 int SIO2_DOWN_FLAG;
+int FARADAYFLAG;
+int i_dom[NXM+1][NYM+1];
+int NOVALLEY[NOAMTIA+1];
 
 // All "real"'s here...
+real MSTAR[NOAMTIA+1][6];
+real XVAL[NOAMTIA+1];
 real u2d[NXM+1][NYM+1][MN3+1];
 real h2d[NXM+1][NYM+1][MN3+1];
 real PSI[NXM+1][NYM+1],E[NXM+1][NYM+1][2];
@@ -97,15 +110,21 @@ real dx,dy;
 real TEMPO=0.,TF;
 real LX,LY;
 real TL,DT;
-real mstar,mstar2,msh;
-real BKTQ,QH,SMH[3],HHM[3],HM[3],GM;
-real SWK[3][14][DIME+1];
-real P[NPMAX+1][7],AF[3],EC[3];
+//real mstar,mstar2;
+real msh;
+real BKTQ,QH,SMH[NOAMTIA+1][3];
+real HHM[NOAMTIA+1][3];
+real HM[NOAMTIA+1][3];
+real GM[NOAMTIA+1];
+real SWK[NOAMTIA+1][3][15][DIME+1];
+real P[NPMAX+1][7];
+real AF[NOAMTIA+1][3];
+real EC[NOAMTIA+1][3];
 real KX,KY,KZ,X,Y;
 real TS,EPP,DDmax;
 real EDGE[4][NXM+NYM+1][4];
-real alphaMATERIAL;
-real epsMATERIAL;
+//real alphaMATERIAL;
+//real epsMATERIAL;
 real CIMP,QD2,TAUW;
 real DG[NXM+1][NYM+1],DL[NXM+1][NYM+1];
 real bufx2d[NXM+1][NYM+1];
@@ -122,6 +141,19 @@ real SIO2_INI[NUMSIO2],SIO2_FIN[NUMSIO2];
 real SIO2_POT[NUMSIO2];
 real SIO2_THICKNESS[NUMSIO2];
 real SIO2[NUMSIO2][NXM+1][NYM+1];
+real B[NXM+1][NYM+1];
+
+real EPSR[NOAMTIA+1];
+real EPF[NOAMTIA+1];
+real alphaK[NOAMTIA+1][4];
+real EMIN[NOAMTIA+1][4];
+real HWO[NOAMTIA+1][6];
+real DTK[NOAMTIA+1][6];
+real ZF[NOAMTIA+1][6];
+real RHO[NOAMTIA+1];
+real DA[NOAMTIA+1];
+real UL[NOAMTIA+1];
+real EG[NOAMTIA+1];
 
 // All structures here...
 time_t binarytime;
@@ -139,6 +171,7 @@ static char *progname;
 int 
 main(int argc,char* argv[])
 {
+  int index;
   int optc;
   int h = 0, v = 0, lose = 0, z = 0;
 
@@ -206,7 +239,7 @@ Report bugs to sellier@dmi.unict.it\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.0.5\n");
+      printf("archimedes - GNU archimedes 0.0.9\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -216,7 +249,7 @@ PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
 of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n",
-              "2004, 2005","Archimedes");
+              "2004, 2005, 2006, 2007","Archimedes");
       exit (0);
     }
   else if (z){
@@ -229,6 +262,120 @@ For more information about these matters, see the file named COPYING.\n",
              progname,argv[1]);
       exit(EXIT_FAILURE);
      }
+// ========================
+// Material constants here!
+// ========================
+// Silicon electrons in the X-valley
+// Germanium electrons in the X-valley
+// All the other semiconductor compounds have electrons in the Gamma- and L-valley
+// definition of the number of valley for every material
+     NOVALLEY[SILICON]=1;
+     NOVALLEY[GERMANIUM]=1;
+     NOVALLEY[GAAS]=2;
+// Relative dielectric constant for Silicon
+     EPSR[SILICON]=11.7;
+// Relative dielectric constant for Germanium
+     EPSR[GERMANIUM]=16.2;
+// Relative dieletric constant for GaAs
+     EPSR[GAAS]=12.90;
+// GaAs high frequency dieletric constant
+     EPF[GAAS]=10.92;
+     for(index=0;index<NOAMTIA;index++){
+       int i;
+       for(i=0;i<6;i++){
+         HWO[index][i]=0.;
+         DTK[index][i]=0.;
+         ZF[index][i]=0.;
+       }
+     }
+// Silicon optical phonon scattering energy (eV)
+     HWO[SILICON][0]=0.0120;
+     HWO[SILICON][1]=0.0185;
+     HWO[SILICON][2]=0.0190;
+     HWO[SILICON][3]=0.0474;
+     HWO[SILICON][4]=0.0612;
+     HWO[SILICON][5]=0.0590;
+// Germanium optical phonon scattering energy (eV)
+     HWO[GERMANIUM][0]=0.09;
+// GaAs optical phonon scattering energy (eV)
+     HWO[GAAS][0]=0.03536;
+// Silicon optical coupling constants (eV/m)
+     DTK[SILICON][0]=0.05e11;
+     DTK[SILICON][1]=0.08e11;
+     DTK[SILICON][2]=0.03e11;
+     DTK[SILICON][3]=0.20e11;
+     DTK[SILICON][4]=1.14e11;
+     DTK[SILICON][5]=0.20e11;
+// Germanium optical coupling constants (eV/m)
+     DTK[GERMANIUM][0]=1.889e11;
+// GaAs optical coupling constant (eV/m)
+     DTK[GAAS][0]=1.11e11;
+// Silicon optical phonon Z-factor
+     ZF[SILICON][0]=1.;
+     ZF[SILICON][1]=1.;
+     ZF[SILICON][2]=4.;
+     ZF[SILICON][3]=4.;
+     ZF[SILICON][4]=1.;
+     ZF[SILICON][5]=4.;
+// Germanium optical phonon Z-factor
+     ZF[GERMANIUM][0]=1.;
+// GaAs optical phonon Z-factor
+     ZF[GAAS][0]=1.;
+// Silicon Crystal Density (Kg/m^3)
+     RHO[SILICON]=2330.;
+// Germanium Crystal Density (Kg/m^3)
+     RHO[GERMANIUM]=5320.;
+// GaAs Crystal Density (Kg/m^3)
+     RHO[GAAS]=5360.;
+// Silicon acoustic deformation potential (Joule)
+     DA[SILICON]=9.*1.60217733e-19;
+// Germanium acoustic deformation potential (Joule)
+     DA[GERMANIUM]=9.*1.60217733e-19;
+// GaAs acoustic deformation potential (Joule)
+     DA[GAAS]=7.*1.60217733e-19;
+// Silicon longitudinal sound velocity (m/sec)
+     UL[SILICON]=9040.;
+// Germanium longitudinal sound velocity (m/sec)
+     UL[GERMANIUM]=5400.;
+// GaAs longitudinal sound velocity (m/sec)
+     UL[GAAS]=5240.;
+// Silicon energy gap
+     EG[SILICON]=1.21-3.333e-4*TL;
+     printf("EG[SILICON]      = %g\n",EG[SILICON]);
+// Germanium energy gap
+     EG[GERMANIUM]=0.747-3.587e-4*TL;
+     printf("EG[GERMANIUM]    = %g\n",EG[GERMANIUM]);
+// GaAs energy gap
+     EG[GAAS]=1.54-4.036e-4*TL;//0.32;???
+     printf("EG[GAAS]         = %g\n",EG[GAAS]);
+     printf("\n");
+// Silicon energy minimum
+     EMIN[SILICON][1]=0.0;
+// Germanium energy minimum
+     EMIN[GERMANIUM][1]=0.173;
+// GaAs energy minimum of GAMMA-valley
+     EMIN[GAAS][1]=0.0;
+// GaAs energy minimum of L-valley (eV)
+     EMIN[GAAS][2]=0.323;
+// Definition of effective mass for all materials in all valleys
+     MSTAR[SILICON][1]=0.32;
+     MSTAR[GAAS][1]=0.067; // Gamma-valley
+     MSTAR[GAAS][2]=0.350; // L-valley
+     MSTAR[GERMANIUM][1]=0.22;
+// non-parabolicity coefficient for Silicon
+     alphaK[SILICON][1]=0.5;
+// non-parabolicity coefficient for Germanium
+     alphaK[GERMANIUM][1]=0.65;
+// non-parabolicity coefficient for GaAs in the GAMMA-valley
+     alphaK[GAAS][1]=pow(1.-MSTAR[GAAS][1],2.)/EG[GAAS];//0.611;
+     printf("alphaK_gamma[GaAs] = %g\n",alphaK[GAAS][1]);
+// non-parabolicity coefficient for GaAs in the L-valley
+     alphaK[GAAS][2]=pow(1.-MSTAR[GAAS][2],2.)/EG[GAAS];//0.242;
+     printf("alphaK_L[GaAs]     = %g\n",alphaK[GAAS][2]);
+     printf("\n");
+// ======================================================
+// ======================================================
+
 // We reset the some arrays
 // ========================
      memset(&u2d,0,sizeof(u2d));
@@ -240,6 +387,7 @@ For more information about these matters, see the file named COPYING.\n",
 // ===========================================================
      Read_Input_File();
 
+
 // Closure of the input file
 // =========================
      fclose(fp);
@@ -258,11 +406,13 @@ For more information about these matters, see the file named COPYING.\n",
 // Boundary conditions for the model simulated
 // ===========================================
      PoissonBCs();
+     if(FARADAYFLAG) FaradayBCs();
 
 // Initialisation for Monte Carlo
 // ==============================
      if(Model_Number==MCE || Model_Number==MCEH){
-      MCparameters();
+      for(index=0;index<NOAMTIA;index++) MCparameters(index);
+      printf("\n");
       MCdevice_config();
      }
 // HERE IS THE SIMULATION
@@ -291,9 +441,10 @@ For more information about these matters, see the file named COPYING.\n",
 // ****************************************************
 
 // =======================================================
-// Modif. 06 ago.2004 - 04 Mar.2005, Siracusa, J.M.Sellier
+// Modif. 06 ago.2004 - 18 Aug.2007, Siracusa, J.M.Sellier
 // =======================================================
 #include "poissonbcs.h"
+#include "faradaybcs.h"
 #include "media.h"
 #include "saveoutput2dmeshformat.h"
 #include "saveoutput2dgnuplot.h"
@@ -301,6 +452,7 @@ For more information about these matters, see the file named COPYING.\n",
 #include "saveoutput2dholemeshformat.h"
 #include "saveoutputfiles.h"
 #include "electric_field.h"
+#include "faraday.h"
 #include "quantumeffectivepotential.h"
 #include "random.h"
 #include "mcparameters.h"
