@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 Oct.2004, Siracusa, J.M.Sellier
-// Last modif. : 24 June 2007, Siracusa, J.M.Sellier
+// Last modif. : 08 August 2007, Siracusa, J.M.Sellier
 // ######################################################
 
 void media(void)
@@ -49,42 +49,28 @@ void media(void)
      ener[i][j]=0.;
    }
  for(n=1;n<=INUM;n++){
+   i=(int)(x+1.5);
+   j=(int)(y+1.5);
+   if(i<1) i=1;
+   if(j<1) j=1;
+   if(i>=nx) i=nx;
+   if(j>=ny) j=ny;
    iv=(int)(P[n][0]);
    x=P[n][5]/dx;
    y=P[n][6]/dy;
    ksquared=P[n][1]*P[n][1]+P[n][2]*P[n][2]+P[n][3]*P[n][3];
-   if(Material==SILICON){
-     thesquareroot=sqrt(1.+4.*alphaSILICON*HHM[0]*ksquared);
-     superparticle_energy=(thesquareroot-1.)/(2.*alphaSILICON);
+   thesquareroot=sqrt(1.+4.*alphaK[i_dom[i][j]][iv]*HHM[i_dom[i][j]][iv]*ksquared);
+   superparticle_energy=(thesquareroot-1.)/(2.*alphaK[i_dom[i][j]][iv]);
 // for the following two rows see
 // pag.10 formula (1.19) of Tomizawa,
 // "Numerical Simulation of Submicron Semiconductor
 //  Devices", 1993, ARTECH HOUSE
 // (this are due to the Kane non-parabolic energy band)
-     xvelocity=P[n][1]*HM[0]/thesquareroot;
-     yvelocity=P[n][2]*HM[0]/thesquareroot;
-   }
-   if(Material==GERMANIUM){
-     thesquareroot=sqrt(1.+4.*alphaGERMANIUM*HHM[0]*ksquared);
-     superparticle_energy=(thesquareroot-1.)/(2.*alphaGERMANIUM);
-     xvelocity=P[n][1]*HM[0]/thesquareroot;
-     yvelocity=P[n][2]*HM[0]/thesquareroot;
-   }
-   if(Material==GAAS){
-     thesquareroot=sqrt(1.+4.*AF[iv]*HHM[iv]*ksquared);
-     superparticle_energy=(thesquareroot-1.)/(2.*AF[iv]);
-     xvelocity=P[n][1]*HM[iv]/thesquareroot;
-     yvelocity=P[n][2]*HM[iv]/thesquareroot;
-   }
-   i=(int)(x+1.5);
-   j=(int)(y+1.5);
-   if(i<1) i=1;
-   if(j<1) j=1;
-   if(i>=nx+1) i=nx+1;
-   if(j>=ny+1) j=ny+1;
+   xvelocity=P[n][1]*HM[i_dom[i][j]][iv]/thesquareroot;
+   yvelocity=P[n][2]*HM[i_dom[i][j]][iv]/thesquareroot;
    cont[i][j]++;
    ener[i][j]+=superparticle_energy;
-   if(iv==2) ener[i][j] += EG_GAAS;
+   if(iv==2) ener[i][j] += EG[i_dom[i][j]];
    xvel[i][j]+=xvelocity;
    yvel[i][j]+=yvelocity;
  }
