@@ -1,5 +1,5 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.0.8.
-   Archimedes is a simulator for Submicron 2D III-V semiconductor
+/* readinputfile.h -- This file is part of Archimedes release 0.0.9.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
@@ -10,7 +10,7 @@
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3, or (at your option)
+   the Free Software Foundation; either version 9, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -26,19 +26,20 @@
 
 // ######################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 18 august 2007, Catania, J.M.Sellier
+// Last modif. : 07 september 2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Read the geometrical and physical description of the device.
 // The input file is interpreted as in a script language.
 // For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.0.7
+// the manual GNU Archimedes release 0.0.9
 
 void
 Read_Input_File(void)
 {
  char s[80];
  double num,num0;
+ double dum;
  int ini,fin;
  int i,j;
  int LXflag=0, LYflag=0;
@@ -50,13 +51,13 @@ Read_Input_File(void)
 // the following values.
 // ============================
  Model_Number=MCE; // here we choose the model
- Material=SILICON; // MESFET made of Silicon
+// Material=SILICON; // MESFET made of Silicon
  nx=50; // default # of cells in x-direction
  ny=50; // default # of cells in y-direction
  TF=5.0e-12; // Default Final Time in seconds
  DT=0.001e-12; // Default constant time step
  TAUW=0.4e-12; // Default Energy relaxation time
- mstar=mstarSILICON; // coefficient of the Si elettronic effective mass
+// mstar=MSTAR[SILICON][1]; // coefficient of the Si elettronic effective mass
  msh=mstarHSILICON; // coefficient of the Si heavy hole effective mass
  FARADAYFLAG=0; // no evolution of magnetic field taken into account as default (B = 0 or const.)
 // standard doping concentration
@@ -66,7 +67,7 @@ Read_Input_File(void)
       h2d[i][j][1]=N_H[i][j]=NI;
       u2d[i][j][2]=u2d[i][j][3]=0.;
       h2d[i][j][2]=h2d[i][j][3]=0.;
-      B[i][j]=0.; // no magnetic field as default
+      i_dom[i][j]=0;
    }
  CIMP=1.e20; // Impurity concentration
  TL=300.; // Lattice temperature in Kelvin
@@ -96,37 +97,36 @@ Processing the input file\n\
   }
 // read and check if the material specified exists
   else if(strcmp(s,"MATERIAL")==0){
+    int type;
+    real xi,xf;
+    real yi,yf;
     fscanf(fp,"%s",s);
-    if(strcmp(s,"SILICON")==0){
-      Material=SILICON;
-      epsMATERIAL=EPSR*EPS0;
-      alphaMATERIAL=alphaSILICON;
-      mstar=mstarSILICON;
-      msh=mstarHSILICON;
-      printf("MATERIAL %s ---> Ok\n",s);
-    }
-    else if(strcmp(s,"GAAS")==0){
-      Material=GAAS;
-      epsMATERIAL=EPS_GAAS*EPS0;
-      alphaMATERIAL=alphaGAAS;
-      mstar=mstarGAAS;
-      mstar2=mstar2GAAS;
-      msh=mstarHGAAS;
-      printf("MATERIAL %s ---> Ok\n",s);
-    }
-    else if(strcmp(s,"GERMANIUM")==0){
-      Material==GERMANIUM;
-      epsMATERIAL=EPSR_Ge*EPS0;
-      alphaMATERIAL=alphaGERMANIUM;
-      mstar=mstarGERMANIUM;
-      msh=mstarHGERMANIUM;
-      printf("MATERIAL %s ---> Ok\n",s);
-    }
-// if the material specified does not exist then exit
+    if(strcmp(s,"X")==0) fscanf(fp,"%lf %lf",&xi,&xf);
     else{
-      printf("%s: unknow specified material\n",progname);
-      exit(EXIT_FAILURE);
+      printf("%s : X material not specified!\n",progname);
+      exit(0);
     }
+    fscanf(fp,"%s",s);
+    if(strcmp(s,"Y")==0) fscanf(fp,"%lf %lf",&yi,&yf);
+    else{
+      printf("%s : Y material not specified!\n",progname);
+      exit(0);
+    }
+    fscanf(fp,"%s",s);
+    if(strcmp(s,"SILICON")==0)        type=SILICON;
+    else if(strcmp(s,"GAAS")==0)      type=GAAS;
+    else if(strcmp(s,"GERMANIUM")==0) type=GERMANIUM;
+    else{
+      printf("%s : unknown specified material!\n",progname);
+      exit(0);
+    }
+    printf("MATERIAL %s X=[%g,%g] Y=[%g,%g] ---> Ok\n",s,xi,xf,yi,yf);
+    for(i=1;i<=nx+4;i++)
+      for(j=1;j<=ny+4;j++)
+        if((i-0.5)*dx>=xi && (i-1.5)*dx<=xf
+         &&(j-0.5)*dy>=yi && (j-1.5)*dy<=yf){
+           i_dom[i][j]=type;
+        }
   }
 // here we choose the charge particle transport simulated
   else if(strcmp(s,"TRANSPORT")==0){
