@@ -1,15 +1,16 @@
-/* saveoutput2dmeshformat.h -- This file is part of Archimedes release 0.0.7.
+/* saveoutput2dmeshformat.h -- This file is part of Archimedes release 0.0.9.
    Archimedes is a simulator for Submicron 2D Silicon/GaAs/Germanium
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   of effective potential method. It is now able to simulate applied
+   magnetic fields along with self consistent Faraday equation.
 
    Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -25,7 +26,7 @@
 
 // ######################################################
 // Created on 24 Apr.2004, Siracusa, J.M.Sellier
-// Last modif. : 27 Dec.2006, Siracusa, J.M.Sellier
+// Last modif. : 07 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -65,14 +66,14 @@ SaveOutput2D_MeshFormat(int je)
   int i,j;
   int size,dim,nbmet,nbval,type;
 
-  printf("SaveOutput3D_MeshFormat\n\n");
+  printf("SaveOutput2D_MeshFormat\n\n");
 
  NUM_VERT=(nx+1)*(ny+1);
  printf("\nNUM_VERT=%d\n",NUM_VERT);
  NUM_EXAHEDRA=nx*ny;
  printf("\nNUM_EXAHEDRA=%d\n",NUM_EXAHEDRA);
 
-if(Material==SILICON || Material==GERMANIUM){
+//if(Material==SILICON || Material==GERMANIUM){
 // Open the files related to electrons
 // ===================================
 if(je<10){
@@ -252,9 +253,9 @@ else{
     fclose(Xp);
     fclose(Yp);
     fclose(Qp);
-}
+//}
 // **************************************************
-if(Material==GAAS){
+/*if(Material==GAAS){
 // Open the files related to electrons
 // ===================================
 if(je<10){
@@ -410,8 +411,8 @@ else{
     fclose(Xp);
     fclose(Yp);
     fclose(Qp);
-}        
- printf("End of SaveOutput3D_MeshFormat\n");
+}        */
+ printf("End of SaveOutput2D_MeshFormat\n");
 }
 
 // =============================================================
